==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Test/Gui/Resources/translations/Test_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hr" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Kvarovi i greške</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Opis</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Kreni</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>&amp;Pomoć</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;O</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>&amp;Zatvori</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt + C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Besposlen</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Napredak</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Preostali:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Pogreške:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Kvarovi:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Pokretanje:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Test</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Odaberite naziv testa:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Pomoć</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>O FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (c) Werner Mayer FreeCAD UnitTest je dio FreeCAD i podržava pisanje jedinica Testovi za vlastite module.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Unesite naziv objekt za zvanje koji, kad se zove,vratit će TestCase.Klik "Start", test će se pokrenuti. Dvaput kliknite na pogreške u prikazu stabla da biste vidjeli više informacija o tome, uključujući i stog trag.</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Test/Gui/Resources/translations/Test_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hr" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Kvarovi i pogreške</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Opis</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Kreni</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>&amp;Pomoć</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;O</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>&amp;Zatvori</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt + C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Besposlen</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Napredak</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Preostali:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Pogreške:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Kvarovi:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Pokretanje:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Test</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Odaberite naziv testa:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Pomoć</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>O FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (c) Werner Mayer FreeCAD UnitTest je dio FreeCAD i podržava pisanje jedinica Testovi za vlastite module.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Unesite naziv objekt za zvanje koji, kad se zove,vratit će TestCase.Klik "Start", test će se pokrenuti. Dvaput kliknite na pogreške u prikazu stabla da biste vidjeli više informacija o tome, uključujući i stog trag.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation>Unesite naziv od opozivog objekta koji kad se pozove, vratiti će TestCase.
Kliknite 'start' i tako pokrenite test.

Duplo kliknite na pogreške u prikazu stabla za više informacija o tome, uključujući i stog praćenje.</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation>Copyright (c) Werner Mayer

FreeCAD UnitTest je dio FreeCAD i podržava pisanje UnitTest bloka za vlastite module.</translation>
    </message>
  </context>
</TS>
